### TODO

- [] Load config for some items
- [] Support metadata
- [x] Publish nostrpy to pypi
- [x] Update README with CI/CD
- [] Update README with package information
- [] Add unit test for CLI

Feel free to add issue(s), add PR(s) for TODO
